gym\_ignition.controllers.gazebo
================================

.. automodule:: gym_ignition.controllers.gazebo
   :members:
   :undoc-members:
   :show-inheritance:


gym\_ignition.controllers.gazebo.computed\_torque\_fixed\_base
--------------------------------------------------------------

.. automodule:: gym_ignition.controllers.gazebo.computed_torque_fixed_base
   :members:
   :undoc-members:
   :show-inheritance:
